package cds.aida.gui;
/* $Id: PropertiesHandler.java,v 1.1 2007/06/04 14:18:21 beugnot Exp $ */
import java.awt.Color;
import java.awt.Dimension;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * Get resource value from property file
 */
public abstract class PropertiesHandler {
	
	protected ResourceBundle rb=null;

	/**
	 * Get value for key
	 * @see Conf#get(String key,String default_value)
	 * @param key
	 * @return key's value or default value
	 */
	public String get(String key) {
		return get(key,null);
	}
	/**
	 * Get value associated with key, with default value.
	 * If default value is null, default is "(key)"
	 * @param key
	 * @param default_value
	 * @return key's value or default if key missing
	 */
	public String get(String key, String default_value) {
		String v;
		try {
			v=rb.getString(key);
		}
		catch(Exception e) {
			Logger.getInstance().log(
					Logger.DEBUG,
					"PropertiesHandler.get("+key+")miss("+default_value+")"); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
			v=(default_value!=null)?default_value:"("+key+")"; //$NON-NLS-1$ //$NON-NLS-2$
		}
		return v;
	}
	
	/**
	 * Get int value associated with key
	 * @param key
	 * @return int value or exception
	 * @throws MissingResourceException if no suitable value.
	 */
	public int getInt(String key)
	throws MissingResourceException {
		return getInt(key,null);
	}
	/**
	 * Does not throw MissingResourceException because int cannot be null,
	 * thus always a default value.
	 * @param resource key
	 * @param i default value
	 * @return
	 */
	public int getInt(String key,int i) {
		return getInt(key,new Integer(i));
	}
	/**
	 * Get int value associated with key
	 * May use default value if key has no suitable value
	 * @param key
	 * @param default_value (if null, might throw exception)
	 * @return int value for key
	 * @throws MissingResourceException if (key missing or key's value not int)
	 * and not default value given
	 */
	public int getInt(String key, Integer default_value)
	throws MissingResourceException {
		String v;
		int val;
		try{
			v=rb.getString(key);
			val=new Integer(v).intValue();
		}
		catch(Exception e) {
			
			if(default_value!=null) {
				return default_value.intValue();
			}
			// otherwise, cannot do better than:
			throw new MissingResourceException(
					"Resource("+key+") missing or not an integer,"+ //$NON-NLS-1$ //$NON-NLS-2$
					" and no usable default value.", //$NON-NLS-1$
					ResourceBundle.class.toString(),
					key
					);
		}
		return val;
	}
	public boolean getBool(String key)
	throws MissingResourceException {
		return getBool(key,null);
	}
	public boolean getBool(String key,boolean b) {
		return getBool(key,new Boolean(b));
	}
	/**
	 * Get boolean value associated with key
	 * May use default value if key has no suitable value
	 * @param key
	 * @param default_value (if null, might throw exception)
	 * @return boolean value for key
	 * @throws MissingResourceException if (key missing or key's value not int)
	 * and not default value given
	 */
	public boolean getBool(String key, Boolean default_value)
	throws MissingResourceException {
		String v;
		boolean val;
		try{
			v=rb.getString(key);
			if(v.equals("1")) { v="true"; } //$NON-NLS-1$ //$NON-NLS-2$
			val=new Boolean(v).booleanValue();
		}
		catch(Exception e) {
			
			if(default_value!=null) {
				return default_value.booleanValue();
			}
			// otherwise, cannot do better than:
			throw new MissingResourceException(
					"Resource("+key+") missing or not an integer,"+ //$NON-NLS-1$ //$NON-NLS-2$
					" and no usable default value.", //$NON-NLS-1$
					ResourceBundle.class.toString(),
					key
					);
		}
		return val;
	}
	/**
	 * Get a Color.
	 * MissingResourceException might occur if no default and
	 * missing or badly formed resource. 
	 */
	public Color getColor(String key, Color default_value) {
		Color c=null;
		String v;
		try{
			v=rb.getString(key);
			String rgb[]=v.split(" *, *"); //$NON-NLS-1$
			Integer r=new Integer(rgb[0]);
			Integer g=new Integer(rgb[1]);
			Integer b=new Integer(rgb[2]);
			c=new Color(r.intValue(),g.intValue(),b.intValue());
		}
		catch(Exception e) {
			Logger.getInstance().log(
					Logger.DEBUG,
					"PropertiesHandler.getColor: color("+key+") error"); //$NON-NLS-1$ //$NON-NLS-2$
			if(default_value!=null) {
				return default_value;
			}
			throw new MissingResourceException(
					"Resource("+key+") missing or not a Color,"+ //$NON-NLS-1$ //$NON-NLS-2$
					" and no usable default value.", //$NON-NLS-1$
					ResourceBundle.class.toString(),
					key
					);
		}
		return c;
	}
	/**
	 * Get a Dimension.
	 * MissingResourceException might occur if no default and
	 * missing or badly formed resource. 
	 */
	public Dimension getDimension(String key, Dimension default_value) {
		Dimension d=null;
		String v;
		try{
			v=rb.getString(key);
			String dim[]=v.split(" *, *"); //$NON-NLS-1$
			Integer x=new Integer(dim[0]);
			Integer y=new Integer(dim[1]);
			d=new Dimension(x.intValue(),y.intValue());
		}
		catch(Exception e) {
			Logger.getInstance().log(
					Logger.DEBUG,
					"PropertiesHandler.getColor: dimension("+key+") error"); //$NON-NLS-1$ //$NON-NLS-2$
			if(default_value!=null) {
				return default_value;
			}
			throw new MissingResourceException(
					"Resource("+key+") missing or not a Dimension,"+ //$NON-NLS-1$ //$NON-NLS-2$
					" and no usable default value.", //$NON-NLS-1$
					ResourceBundle.class.toString(),
					key
					);
		}
		return d;
	}
}
